@@ -36,15 +36,18 @@ import shutil
 import stat
 import sys
 import time
+from typing import List
 
 import SCons.Action
 import SCons.Builder
 import SCons.CacheDir
 import SCons.Environment
+import SCons.Errors
 import SCons.PathList
 import SCons.Scanner.Dir
 import SCons.Subst
 import SCons.Tool
+from SCons.Util import is_List, is_String, is_Sequence, is_Tuple, is_Dict, flatten
 
 # A placeholder for a default Environment (for fetching source files
 # from source code management systems and the like).  This must be
@@ -79,7 +82,6 @@ def DefaultEnvironment(*args, **kw):
     """
     global _default_env
     if not _default_env:
-        import SCons.Util
         _default_env = SCons.Environment.Environment(*args, **kw)
         _default_env.Decider('content')
         global DefaultEnvironment
@@ -157,15 +159,19 @@ LdModuleLinkAction = SCons.Action.Action("$LDMODULECOM", "$LDMODULECOMSTR")
 ActionFactory = SCons.Action.ActionFactory
 
 
-def get_paths_str(dest):
-    # If dest is a list, we need to manually call str() on each element
-    if SCons.Util.is_List(dest):
-        elem_strs = []
-        for element in dest:
-            elem_strs.append('"' + str(element) + '"')
-        return '[' + ', '.join(elem_strs) + ']'
+def get_paths_str(dest) -> str:
+    """Generates a string from *dest* for use in a strfunction.
+
+    If *dest* is a list, manually converts each elem to a string.
+    """
+    def quote(arg):
+        return f'"{arg}"'
+
+    if is_List(dest):
+        elem_strs = [quote(d) for d in dest]
+        return f'[{", ".join(elem_strs)}]'
     else:
-        return '"' + str(dest) + '"'
+        return quote(dest)
 
 
 permission_dic = {
@@ -187,15 +193,21 @@ permission_dic = {
 }
 
 
-def chmod_func(dest, mode):
-    import SCons.Util
+def chmod_func(dest, mode) -> None:
+    """Implementation of the Chmod action function.
+
+    *mode* can be either an integer (normally expressed in octal mode,
+    as in 0o755) or a string following the syntax of the POSIX chmod
+    command (for example "ugo+w"). The latter must be converted, since
+    the underlying Python only takes the numeric form.
+    """
     from string import digits
     SCons.Node.FS.invalidate_node_memos(dest)
-    if not SCons.Util.is_List(dest):
+    if not is_List(dest):
         dest = [dest]
-    if SCons.Util.is_String(mode) and 0 not in [i in digits for i in mode]:
+    if is_String(mode) and 0 not in [i in digits for i in mode]:
         mode = int(mode, 8)
-    if not SCons.Util.is_String(mode):
+    if not is_String(mode):
         for element in dest:
             os.chmod(str(element), mode)
     else:
@@ -231,57 +243,87 @@ def chmod_func(dest, mode):
                     os.chmod(str(element), curr_perm & ~new_perm)
 
 
-def chmod_strfunc(dest, mode):
-    import SCons.Util
-    if not SCons.Util.is_String(mode):
-        return 'Chmod(%s, 0%o)' % (get_paths_str(dest), mode)
+def chmod_strfunc(dest, mode) -> str:
+    """strfunction for the Chmod action function."""
+    if not is_String(mode):
+        return f'Chmod({get_paths_str(dest)}, {mode:#o})'
     else:
-        return 'Chmod(%s, "%s")' % (get_paths_str(dest), str(mode))
+        return f'Chmod({get_paths_str(dest)}, "{mode}")'
+
 
 
 Chmod = ActionFactory(chmod_func, chmod_strfunc)
 
 
-def copy_func(dest, src, symlinks=True):
-    """
-    If symlinks (is true), then a symbolic link will be
+
+def copy_func(dest, src, symlinks=True) -> int:
+    """Implementation of the Copy action function.
+
+    Copies *src* to *dest*.  If *src* is a list, *dest* must be
+    a directory, or not exist (will be created).
+
+    Since Python :mod:`shutil` methods, which know nothing about
+    SCons Nodes, will be called to perform the actual copying,
+    args are converted to strings first.
+
+    If *symlinks* evaluates true, then a symbolic link will be
     shallow copied and recreated as a symbolic link; otherwise, copying
     a symbolic link will be equivalent to copying the symbolic link's
     final target regardless of symbolic link depth.
     """
 
     dest = str(dest)
-    src = str(src)
+    src = [str(n) for n in src] if is_List(src) else str(src)
 
     SCons.Node.FS.invalidate_node_memos(dest)
-    if SCons.Util.is_List(src) and os.path.isdir(dest):
+    if is_List(src):
+        # this fails only if dest exists and is not a dir
+        try:
+            os.makedirs(dest, exist_ok=True)
+        except FileExistsError:
+            raise SCons.Errors.BuildError(
+                errstr=(
+                    'Error: Copy() called with a list of sources, '
+                    'which requires target to be a directory, '
+                    f'but "{dest}" is not a directory.'
+                )
+            )
         for file in src:
             shutil.copy2(file, dest)
         return 0
+
     elif os.path.islink(src):
         if symlinks:
-            return os.symlink(os.readlink(src), dest)
-        else:
-            return copy_func(dest, os.path.realpath(src))
+            os.symlink(os.readlink(src), dest)
+            return 0
+
+        return copy_func(dest, os.path.realpath(src))
+
     elif os.path.isfile(src):
         shutil.copy2(src, dest)
         return 0
+
     else:
         shutil.copytree(src, dest, symlinks)
-        # copytree returns None in python2 and destination string in python3
-        # A error is raised in both cases, so we can just return 0 for success
         return 0
 
 
-Copy = ActionFactory(
-    copy_func,
-    lambda dest, src, symlinks=True: 'Copy("%s", "%s")' % (dest, src)
-)
+def copy_strfunc(dest, src, symlinks=True) -> str:
+    """strfunction for the Copy action function."""
+    return f'Copy({get_paths_str(dest)}, {get_paths_str(src)})'
 
 
-def delete_func(dest, must_exist=0):
+Copy = ActionFactory(copy_func, copy_strfunc)
+
+
+def delete_func(dest, must_exist=False) -> None:
+    """Implementation of the Delete action function.
+
+    Lets the Python :func:`os.unlink` raise an error if *dest* does not exist,
+    unless *must_exist* evaluates false (the default).
+    """
     SCons.Node.FS.invalidate_node_memos(dest)
-    if not SCons.Util.is_List(dest):
+    if not is_List(dest):
         dest = [dest]
     for entry in dest:
         entry = str(entry)
@@ -296,39 +338,42 @@ def delete_func(dest, must_exist=0):
         os.unlink(entry)
 
 
-def delete_strfunc(dest, must_exist=0):
-    return 'Delete(%s)' % get_paths_str(dest)
+def delete_strfunc(dest, must_exist=False) -> str:
+    """strfunction for the Delete action function."""
+    return f'Delete({get_paths_str(dest)})'
 
 
 Delete = ActionFactory(delete_func, delete_strfunc)
 
 
-def mkdir_func(dest):
+def mkdir_func(dest) -> None:
+    """Implementation of the Mkdir action function."""
     SCons.Node.FS.invalidate_node_memos(dest)
-    if not SCons.Util.is_List(dest):
+    if not is_List(dest):
         dest = [dest]
     for entry in dest:
         os.makedirs(str(entry), exist_ok=True)
 
 
-Mkdir = ActionFactory(mkdir_func,
-                      lambda _dir: 'Mkdir(%s)' % get_paths_str(_dir))
+Mkdir = ActionFactory(mkdir_func, lambda _dir: f'Mkdir({get_paths_str(_dir)})')
 
 
-def move_func(dest, src):
+def move_func(dest, src) -> None:
+    """Implementation of the Move action function."""
     SCons.Node.FS.invalidate_node_memos(dest)
     SCons.Node.FS.invalidate_node_memos(src)
     shutil.move(src, dest)
 
 
-Move = ActionFactory(move_func,
-                     lambda dest, src: 'Move("%s", "%s")' % (dest, src),
-                     convert=str)
+Move = ActionFactory(
+    move_func, lambda dest, src: f'Move("{dest}", "{src}")', convert=str
+)
 
 
-def touch_func(dest):
+def touch_func(dest) -> None:
+    """Implementation of the Touch action function."""
     SCons.Node.FS.invalidate_node_memos(dest)
-    if not SCons.Util.is_List(dest):
+    if not is_List(dest):
         dest = [dest]
     for file in dest:
         file = str(file)
@@ -341,8 +386,7 @@ def touch_func(dest):
         os.utime(file, (atime, mtime))
 
 
-Touch = ActionFactory(touch_func,
-                      lambda file: 'Touch(%s)' % get_paths_str(file))
+Touch = ActionFactory(touch_func, lambda file: f'Touch({get_paths_str(file)})')
 
 
 # Internal utility functions
@@ -390,7 +434,7 @@ def _concat_ixes(prefix, items_iter, suffix, env):
     prefix = str(env.subst(prefix, SCons.Subst.SUBST_RAW))
     suffix = str(env.subst(suffix, SCons.Subst.SUBST_RAW))
 
-    for x in SCons.Util.flatten(items_iter):
+    for x in flatten(items_iter):
         if isinstance(x, SCons.Node.FS.File):
             result.append(x)
             continue
@@ -436,8 +480,8 @@ def _stripixes(prefix, itms, suffix, stripprefixes, stripsuffixes, env, c=None):
         else:
             c = _concat_ixes
 
-    stripprefixes = list(map(env.subst, SCons.Util.flatten(stripprefixes)))
-    stripsuffixes = list(map(env.subst, SCons.Util.flatten(stripsuffixes)))
+    stripprefixes = list(map(env.subst, flatten(stripprefixes)))
+    stripsuffixes = list(map(env.subst, flatten(stripsuffixes)))
 
     stripped = []
     for l in SCons.PathList.PathList(itms).subst_path(env, None, None):
@@ -445,7 +489,7 @@ def _stripixes(prefix, itms, suffix, stripprefixes, stripsuffixes, env, c=None):
             stripped.append(l)
             continue
 
-        if not SCons.Util.is_String(l):
+        if not is_String(l):
             l = str(l)
 
         for stripprefix in stripprefixes:
@@ -467,53 +511,82 @@ def _stripixes(prefix, itms, suffix, stripprefixes, stripsuffixes, env, c=None):
     return c(prefix, stripped, suffix, env)
 
 
-def processDefines(defs):
-    """process defines, resolving strings, lists, dictionaries, into a list of
-    strings
+def processDefines(defs) -> List[str]:
+    """Return list of strings for preprocessor defines from *defs*.
+
+    Resolves the different forms ``CPPDEFINES`` can be assembled in:
+    if the Append/Prepend routines are used beyond a initial setting it
+    will be a deque, but if written to only once (Environment initializer,
+    or direct write) it can be a multitude of types.
+
+    Any prefix/suffix is handled elsewhere (usually :func:`_concat_ixes`).
+
+    .. versionchanged:: 4.5.0
+       Bare tuples are now treated the same as tuple-in-sequence, assumed
+       to describe a valued macro. Bare strings are now split on space.
+       A dictionary is no longer sorted before handling.
     """
-    if SCons.Util.is_List(defs):
-        l = []
-        for d in defs:
-            if d is None:
+    dlist = []
+    if is_List(defs):
+        for define in defs:
+            if define is None:
                 continue
-            elif SCons.Util.is_List(d) or isinstance(d, tuple):
-                if len(d) >= 2:
-                    l.append(str(d[0]) + '=' + str(d[1]))
+            elif is_Sequence(define):
+                if len(define) > 2:
+                    raise SCons.Errors.UserError(
+                        f"Invalid tuple in CPPDEFINES: {define!r}, "
+                        "must be a tuple with only two elements"
+                    )
+                name, *value = define
+                if value and value[0] is not None:
+                    # TODO: do we need to quote value if it contains space?
+                    dlist.append(f"{name}={value[0]}")
                 else:
-                    l.append(str(d[0]))
-            elif SCons.Util.is_Dict(d):
-                for macro, value in d.items():
+                    dlist.append(str(define[0]))
+            elif is_Dict(define):
+                for macro, value in define.items():
                     if value is not None:
-                        l.append(str(macro) + '=' + str(value))
+                        # TODO: do we need to quote value if it contains space?
+                        dlist.append(f"{macro}={value}")
                     else:
-                        l.append(str(macro))
-            elif SCons.Util.is_String(d):
-                l.append(str(d))
+                        dlist.append(str(macro))
+            elif is_String(define):
+                dlist.append(str(define))
             else:
-                raise SCons.Errors.UserError("DEFINE %s is not a list, dict, string or None." % repr(d))
-    elif SCons.Util.is_Dict(defs):
-        # The items in a dictionary are stored in random order, but
-        # if the order of the command-line options changes from
-        # invocation to invocation, then the signature of the command
-        # line will change and we'll get random unnecessary rebuilds.
-        # Consequently, we have to sort the keys to ensure a
-        # consistent order...
-        l = []
-        for k, v in sorted(defs.items()):
-            if v is None:
-                l.append(str(k))
+                raise SCons.Errors.UserError(
+                    f"CPPDEFINES entry {define!r} is not a tuple, list, "
+                    "dict, string or None."
+                )
+    elif is_Tuple(defs):
+        if len(defs) > 2:
+            raise SCons.Errors.UserError(
+                f"Invalid tuple in CPPDEFINES: {defs!r}, "
+                "must be a tuple with only two elements"
+            )
+        name, *value = defs
+        if value and value[0] is not None:
+            # TODO: do we need to quote value if it contains space?
+            dlist.append(f"{name}={value[0]}")
+        else:
+            dlist.append(str(define[0]))
+    elif is_Dict(defs):
+        for macro, value in defs.items():
+            if value is None:
+                dlist.append(str(macro))
             else:
-                l.append(str(k) + '=' + str(v))
+                dlist.append(f"{macro}={value}")
+    elif is_String(defs):
+        return defs.split()
     else:
-        l = [str(defs)]
-    return l
+        dlist.append(str(defs))
+
+    return dlist
 
 
 def _defines(prefix, defs, suffix, env, target=None, source=None, c=_concat_ixes):
-    """A wrapper around _concat_ixes that turns a list or string
+    """A wrapper around :func:`_concat_ixes` that turns a list or string
     into a list of C preprocessor command-line definitions.
     """
-
     return c(prefix, env.subst_list(processDefines(defs), target=target, source=source), suffix, env)
 
 
