@@ -1,5 +1,6 @@
+# MIT License
 #
-# __COPYRIGHT__
+# Copyright The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -19,8 +20,6 @@
 # LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-#
-__revision__ = "__FILE__ __REVISION__ __DATE__ __DEVELOPER__"
 
 import atexit
 import unittest
@@ -30,7 +29,6 @@ import TestUnit
 import cpp
 
 
-
 basic_input = """
 #include "file1-yes"
 #include <file2-yes>
@@ -57,6 +55,8 @@ substitution_input = """
 
 #include XXX_FILE5
 #include XXX_FILE6
+
+#include SHELL_ESCAPED_H
 """
 
 
@@ -443,7 +443,8 @@ if_no_space_input = """
 class cppTestCase(unittest.TestCase):
     def setUp(self):
         self.cpp = self.cpp_class(current = ".",
-                                  cpppath = ['/usr/include'])
+                                  cpppath = ['/usr/include'],
+                                  dict={"SHELL_ESCAPED_H": '\\"file-shell-computed-yes\\"'})
 
     def test_basic(self):
         """Test basic #include scanning"""
@@ -533,6 +534,7 @@ class cppAllTestCase(cppTestCase):
     def setUp(self):
         self.cpp = self.cpp_class(current = ".",
                                   cpppath = ['/usr/include'],
+                                  dict={"SHELL_ESCAPED_H": '\\"file-shell-computed-yes\\"'},
                                   all=1)
 
 class PreProcessorTestCase(cppAllTestCase):
@@ -548,6 +550,7 @@ class PreProcessorTestCase(cppAllTestCase):
         ('include', '<', 'file4-yes'),
         ('include', '"', 'file5-yes'),
         ('include', '<', 'file6-yes'),
+        ('include', '"', 'file-shell-computed-yes'),
     ]
 
     ifdef_expect = [
@@ -649,6 +652,7 @@ class DumbPreProcessorTestCase(cppAllTestCase):
         ('include', '<', 'file4-yes'),
         ('include', '"', 'file5-yes'),
         ('include', '<', 'file6-yes'),
+        ('include', '"', 'file-shell-computed-yes'),
     ]
 
     ifdef_expect = [
@@ -855,7 +859,7 @@ class fileTestCase(unittest.TestCase):
         """)
         class MyPreProcessor(cpp.DumbPreProcessor):
             def __init__(self, *args, **kw):
-                cpp.DumbPreProcessor.__init__(self, *args, **kw)
+                super().__init__(*args, **kw)
                 self.files = []
             def __call__(self, file):
                 self.files.append(file)
@@ -878,12 +882,13 @@ if __name__ == '__main__':
                  fileTestCase,
                ]
     for tclass in tclasses:
-        names = unittest.getTestCaseNames(tclass, 'test_')
+        loader = unittest.TestLoader()
+        loader.testMethodPrefix = 'test_'
+        names = loader.getTestCaseNames(tclass)
         try:
-            names = list(set(names))
+            names = sorted(set(names))
         except NameError:
             pass
-        names.sort()
         suite.addTests(list(map(tclass, names)))
     TestUnit.run(suite)
 
