@@ -26,7 +26,8 @@ __revision__ = "__FILE__ __REVISION__ __DATE__ __DEVELOPER__"
 
 """
 Test that we can actually build a simple program using our generated
-Visual Studio 6 project (.dsp) and solution (.dsw) files.
+Visual Studio 14.0 project (.vcxproj) and solution (.sln) files
+using Visual Studio 14.2
 """
 
 import os
@@ -40,7 +41,7 @@ if sys.platform != 'win32':
     msg = "Skipping Visual Studio test on non-Windows platform '%s'\n" % sys.platform
     test.skip_test(msg)
 
-msvs_version = '6.0'
+msvs_version = '14.2'
 
 if not msvs_version in test.msvs_versions():
     msg = "Visual Studio %s not installed; skipping test.\n" % msvs_version
@@ -50,7 +51,7 @@ if not msvs_version in test.msvs_versions():
 
 # Let SCons figure out the Visual Studio environment variables for us and
 # print out a statement that we can exec to suck them into our external
-# environment so we can execute msdev and really try to build something.
+# environment so we can execute devenv and really try to build something.
 
 test.run(arguments = '-n -q -Q -f -', stdin = """\
 env = Environment(tools = ['msvc'], MSVS_VERSION='%(msvs_version)s')
@@ -58,7 +59,7 @@ if env.WhereIs('cl'):
     print("os.environ.update(%%s)" %% repr(env['ENV']))
 """ % locals())
 
-if test.stdout() == "":
+if(test.stdout() == ""):
     msg = "Visual Studio %s missing cl.exe; skipping test.\n" % msvs_version
     test.skip_test(msg)
 
@@ -71,15 +72,16 @@ test.subdir('sub dir')
 test.write(['sub dir', 'SConstruct'], """\
 env=Environment(MSVS_VERSION = '%(msvs_version)s')
 
-env.MSVSProject(target = 'foo.dsp',
+env.MSVSProject(target = 'foo.vcxproj',
                 srcs = ['foo.c'],
                 buildtarget = 'foo.exe',
-                variant = 'Release')
-
+                variant = 'Release',
+                DebugSettings = {'LocalDebuggerCommandArguments':'echo "<foo.c>" > output.txt'})
 env.Program('foo.c')
 """ % locals())
 
 test.write(['sub dir', 'foo.c'], r"""
+#include <stdio.h>
 int
 main(int argc, char *argv)
 {
@@ -90,12 +92,18 @@ main(int argc, char *argv)
 
 test.run(chdir='sub dir', arguments='.')
 
+test.vcproj_sys_path(test.workpath('sub dir', 'foo.vcxproj'))
+
+import SCons.Platform.win32
+system_dll_path = os.path.join( SCons.Platform.win32.get_system_root(), 'System32' )
+os.environ['PATH'] = os.environ['PATH'] + os.pathsep + system_dll_path
+
 test.run(chdir='sub dir',
          program=[test.get_msvs_executable(msvs_version)],
-         arguments=['Test.dsp', '/MAKE', 'foo - Win32 Release'])
+         arguments=['foo.sln', '/build', 'Release'])
 
 test.run(program=test.workpath('sub dir', 'foo'), stdout="foo.c\n")
-
+test.validate_msvs_file(test.workpath('sub dir', 'foo.vcxproj.user'))
 
 
 test.pass_test()
