@@ -1,6 +1,8 @@
 #!/usr/bin/env python
 #
-# __COPYRIGHT__
+# MIT License
+#
+# Copyright The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -20,9 +22,6 @@
 # LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-#
-
-__revision__ = "__FILE__ __REVISION__ __DATE__ __DEVELOPER__"
 
 """
 Test the BoolVariable canned Variable type.
@@ -40,18 +39,18 @@ def check(expect):
     assert result[1:len(expect)+1] == expect, (result[1:len(expect)+1], expect)
 
 
-
 test.write(SConstruct_path, """\
 from SCons.Variables.BoolVariable import BoolVariable
+
 BV = BoolVariable
 
 from SCons.Variables import BoolVariable
 
 opts = Variables(args=ARGUMENTS)
 opts.AddVariables(
-    BoolVariable('warnings', 'compilation with -Wall and similiar', 1),
-    BV('profile', 'create profiling informations', 0),
-    )
+    BoolVariable('warnings', 'compilation with -Wall and similiar', True),
+    BV('profile', 'create profiling informations', False),
+)
 
 env = Environment(variables=opts)
 Help(opts.GenerateHelpText(env))
@@ -62,8 +61,6 @@ print(env['profile'])
 Default(env.Alias('dummy', None))
 """)
 
-
-
 test.run()
 check([str(True), str(False)])
 
@@ -73,12 +70,10 @@ check([str(False), str(True)])
 expect_stderr = """
 scons: *** Error converting option: warnings
 Invalid value for boolean option: irgendwas
-""" + test.python_file_line(SConstruct_path, 12)
+""" + test.python_file_line(SConstruct_path, 13)
 
 test.run(arguments='warnings=irgendwas', stderr = expect_stderr, status=2)
 
-
-
 test.pass_test()
 
 # Local Variables:
