@@ -2,16 +2,19 @@ r"""
 Phony tool to modify a file in place for testing SCons.
 
 Drops lines that match a pattern.  Currently used to test
-ranlib-related behavior without invoking ranlib.
+ranlib and ar behavior without actually invoking those tools.
 """
 
 import sys
 
-if __name__ == '__main__':
-    line = ('/*' + sys.argv[1] + '*/\n').encode()
+def rewrite():
+    line = ('/*' + sys.argv[1] + '*/\n').encode('utf-8')
     with open(sys.argv[2], 'rb') as ifp:
         lines = [ln for ln in ifp if ln != line]
     with open(sys.argv[2], 'wb') as ofp:
-        for ln in lines:
-            ofp.write(ln)
+        ofp.writelines(lines)
+
+
+if __name__ == '__main__':
+    rewrite()
     sys.exit(0)
